=====
Usage
=====

To use bs_ds in a project::

    # For best experience: 
    from bs_ds import *
    
    # Recommended handle
    import bs_ds as bs

To use bs_ds in an online learn.co lesson::
    
    !pip install bs_ds
    from bs_ds import *
